@@ -36,14 +36,6 @@ int main(int argc, char **argv)
     exit(2);
   }
 
-  if (argc < 2)
-  {
-    fprintf (stderr,
-             "Command line usage: %s [flags] -- prefix [recipients]\n",
-             argv[0]);
-    return 1;
-  }
-
   opt = opts;
   *opt++ = argv[1];
   pfx = NULL;
